badwing.characters.butterfly package
====================================

Submodules
----------

badwing.characters.butterfly.brain module
-----------------------------------------

.. automodule:: badwing.characters.butterfly.brain
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.butterfly.butterfly module
---------------------------------------------

.. automodule:: badwing.characters.butterfly.butterfly
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.butterfly.sprite module
------------------------------------------

.. automodule:: badwing.characters.butterfly.sprite
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.characters.butterfly
   :members:
   :undoc-members:
   :show-inheritance:
